pub enum CredentialsStoreConfig {
Keyring,
Memory,
EncryptedFile {
path: Option<PathBuf>,
password_env: Option<String>,
},
}Variants
Keyring
Holds credentials in the OS keyring
Memory
Holds credentials in-memory and only for the lifetime of the process. Intended for tests and ephemeral runs that must not touch the OS keychain.
EncryptedFile
Holds credentials in an encrypted file