pub struct OtlpTelemetrySettings {
pub endpoint: Option<String>,
pub traces_endpoint: Option<String>,
pub metrics_endpoint: Option<String>,
pub headers: BTreeMap<String, String>,
}Fields
endpoint: Option<String>Base URL for an OTLP/HTTP collector. Aether appends /v1/traces or
/v1/metrics for the respective signal.
traces_endpoint: Option<String>Exact OTLP/HTTP trace export URL. Overrides the traces URL derived from
endpoint, for providers that require a signal-specific endpoint.
metrics_endpoint: Option<String>Exact OTLP/HTTP metric export URL. Overrides the metrics URL derived from
endpoint, for providers that require a signal-specific endpoint.
headers: BTreeMap<String, String>Trait Implementations
Sourceimpl Clone for OtlpTelemetrySettings
impl Clone for OtlpTelemetrySettings
Sourcefn clone(&self) -> OtlpTelemetrySettings
fn clone(&self) -> OtlpTelemetrySettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OtlpTelemetrySettings
impl Debug for OtlpTelemetrySettings
Sourceimpl Default for OtlpTelemetrySettings
impl Default for OtlpTelemetrySettings
Sourcefn default() -> OtlpTelemetrySettings
fn default() -> OtlpTelemetrySettings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OtlpTelemetrySettings
impl<'de> Deserialize<'de> for OtlpTelemetrySettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OtlpTelemetrySettings
Sourceimpl JsonSchema for OtlpTelemetrySettings
impl JsonSchema for OtlpTelemetrySettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OtlpTelemetrySettings
impl PartialEq for OtlpTelemetrySettings
Sourceimpl Serialize for OtlpTelemetrySettings
impl Serialize for OtlpTelemetrySettings
impl StructuralPartialEq for OtlpTelemetrySettings