pub struct TelemetrySignalSettings {
pub enabled: Option<bool>,
}Fields
enabled: Option<bool>Trait Implementations
Sourceimpl Clone for TelemetrySignalSettings
impl Clone for TelemetrySignalSettings
Sourcefn clone(&self) -> TelemetrySignalSettings
fn clone(&self) -> TelemetrySignalSettings
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TelemetrySignalSettings
impl Debug for TelemetrySignalSettings
Sourceimpl Default for TelemetrySignalSettings
impl Default for TelemetrySignalSettings
Sourcefn default() -> TelemetrySignalSettings
fn default() -> TelemetrySignalSettings
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TelemetrySignalSettings
impl<'de> Deserialize<'de> for TelemetrySignalSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TelemetrySignalSettings
Sourceimpl JsonSchema for TelemetrySignalSettings
impl JsonSchema for TelemetrySignalSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TelemetrySignalSettings
impl PartialEq for TelemetrySignalSettings
Sourceimpl Serialize for TelemetrySignalSettings
impl Serialize for TelemetrySignalSettings
impl StructuralPartialEq for TelemetrySignalSettings