pub fn agent_config(name: &str) -> AgentConfigExpand description
A user-invocable AgentConfig named name whose prompt is the file PROMPT.md.
pub fn agent_config(name: &str) -> AgentConfigA user-invocable AgentConfig named name whose prompt is the file PROMPT.md.