Module aether_settings

Module aether_settings 

Structs

AetherSettings
The root of an Aether settings file (.aether/settings.json). It selects the default agent and defines the agents, prompt sources, MCP servers, and provider overrides available to a project.
SettingsFileSource

Enums

AetherSettingsSource
CredentialsStoreConfig

Functions

project_settings_exist
project_settings_path
settings_resource_root
Root that file-backed settings resources resolve against for the settings file at settings_path: the project root (the parent of .aether) when the settings file lives in a .aether directory, otherwise the settings file’s directory.
user_settings_exist
user_settings_path