Structs
- Aether
Settings - The root of an Aether settings file (
.aether/settings.json). It selects the default agent and defines the agents, prompt sources, MCP servers, and provider overrides available to a project. - Settings
File Source
Enums
Functions
- project_
settings_ exist - project_
settings_ path - settings_
resource_ root - Root that file-backed settings resources resolve against for the settings file at
settings_path: the project root (the parent of.aether) when the settings file lives in a.aetherdirectory, otherwise the settings file’s directory. - user_
settings_ exist - user_
settings_ path