Structs
- Aether
Settings - The root of an Aether settings file (
.aether/settings.json). It selects the default agent and defines the agents, prompt sources, MCP servers, and provider overrides available to a project. - Settings
File Source
.aether/settings.json). It selects the
default agent and defines the agents, prompt sources, MCP servers, and provider
overrides available to a project.