load_agent_catalog

Function load_agent_catalog 

pub fn load_agent_catalog(
    project_root: &Path,
) -> Result<AgentCatalog, SettingsError>
Load and resolve the agent catalog from a project root.

If .aether/settings.json is absent, returns a valid empty catalog. If the settings file is malformed or contains invalid entries, returns an error.