pub struct AgentConfig {
pub name: String,
pub description: String,
pub model: String,
pub reasoning_effort: Option<ReasoningEffort>,
pub user_invocable: bool,
pub agent_invocable: bool,
pub prompts: Vec<PromptSource>,
pub mcps: Vec<McpSourceSpec>,
pub tools: ToolFilter,
}Fields
name: Stringdescription: Stringmodel: Stringreasoning_effort: Option<ReasoningEffort>user_invocable: boolagent_invocable: boolprompts: Vec<PromptSource>mcps: Vec<McpSourceSpec>tools: ToolFilterTrait Implementations
Sourceimpl Clone for AgentConfig
impl Clone for AgentConfig
Sourcefn clone(&self) -> AgentConfig
fn clone(&self) -> AgentConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentConfig
impl Debug for AgentConfig
Sourceimpl Default for AgentConfig
impl Default for AgentConfig
Sourcefn default() -> AgentConfig
fn default() -> AgentConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AgentConfig
impl<'de> Deserialize<'de> for AgentConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AgentConfig
impl JsonSchema for AgentConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AgentConfig
impl PartialEq for AgentConfig
Sourcefn eq(&self, other: &AgentConfig) -> bool
fn eq(&self, other: &AgentConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentConfig
impl Serialize for AgentConfig
impl StructuralPartialEq for AgentConfig